hepstats.hypotests.core.discovery module
========================================

.. automodule:: hepstats.hypotests.core.discovery
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
